import './styles.scss';

const accordionsContent = [
	{
		title: 'Título 01',
		content:
			'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc erat quam, pulvinar ut iaculis vitae, eleifend a nulla. Vestibulum dictum semper ligula non vulputate. Nam ultricies iaculis purus pretium vulputate.',
		hidden: false,
	},
	{
		title: 'Título 02',
		content:
			'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc erat quam, pulvinar ut iaculis vitae, eleifend a nulla. Vestibulum dictum semper ligula non vulputate. Nam ultricies iaculis purus pretium vulputate.',
		hidden: true,
	},
	{
		title: 'Título 04',
		content:
			'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc erat quam, pulvinar ut iaculis vitae, eleifend a nulla. Vestibulum dictum semper ligula non vulputate. Nam ultricies iaculis purus pretium vulputate.',
		hidden: false,
		order: 4,
	},
	{
		title: 'Título 03',
		content:
			'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nunc erat quam, pulvinar ut iaculis vitae, eleifend a nulla. Vestibulum dictum semper ligula non vulputate. Nam ultricies iaculis purus pretium vulputate.',
		hidden: false,
		order: 3,
	},
];

const defaultOptions = {
	targetElement: 'body',
	contentArray: accordionsContent,
	elementsPerRow: '2',
	arrowDown:
		'<svg aria-hidden="true" focusable="false" data-prefix="fas" data-icon="chevron-down" class="accordion__arrow svg-inline--fa fa-chevron-down fa-w-14" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path fill="currentColor" d="M207.029 381.476L12.686 187.132c-9.373-9.373-9.373-24.569 0-33.941l22.667-22.667c9.357-9.357 24.522-9.375 33.901-.04L224 284.505l154.745-154.021c9.379-9.335 24.544-9.317 33.901.04l22.667 22.667c9.373 9.373 9.373 24.569 0 33.941L240.971 381.476c-9.373 9.372-24.569 9.372-33.942 0z"></path></svg>',
	titleClass: 'my-title',
	contentClass: '',
};

export default class Accordion {
	/**
	 * Creates an instance of Accordion.
	 * @param {Object} userOptions - Opções a serem usadas para construir o Accordion
	 * @memberof Accordion
	 */
	constructor(userOptions) {
		this.options = Object.assign(defaultOptions, userOptions);

		/* Limpando o conteúdo que existe dentro do targetElement */
		const tempNode = document
			.querySelector(this.options.targetElement)
			.cloneNode(false);
		document
			.querySelector(this.options.targetElement)
			.parentNode.replaceChild(
				tempNode,
				document.querySelector(this.options.targetElement)
			);
		this.buildFields();
	}

	/**
	 * Constroi os accordions de acordo com o conteúdo do options.contentArray
	 *
	 * @memberof Accordion
	 */
	buildFields() {
		for (let i = 0; i < this.options.contentArray.length; i += 1) {
			const accordionDiv = document.createElement('div');
			accordionDiv.classList.add('accordion');
			const titleDiv = document.createElement('div');
			titleDiv.classList.add('accordion__title');
			const titleElement = document.createElement('h5');
			if (this.options.contentArray[i].title)
				titleElement.innerHTML = this.options.contentArray[i].title;
			else titleElement.innerHTML = 'Placeholder Title';
			if (this.options.titleClass)
				titleElement.classList.add(this.options.titleClass);
			titleDiv.appendChild(titleElement);
			const arrowElement = document.createElement('div');
			titleDiv.append(arrowElement);
			arrowElement.outerHTML = this.options.arrowDown;
			accordionDiv.appendChild(titleDiv);

			const contentDiv = document.createElement('div');
			contentDiv.classList.add('accordion__content');
			const contentElement = document.createElement('p');
			if (this.options.contentArray[i].content)
				contentElement.innerHTML = this.options.contentArray[i].content;
			else contentElement.innerHTML = 'Placeholder Content';
			if (this.options.contentClass)
				contentElement.classList.add(this.options.contentClass);
			if (this.options.contentArray[i].hidden) {
				contentDiv.classList.add('hidden');
				titleDiv.querySelector('.accordion__arrow').classList.add('hidden');
			}

			contentDiv.appendChild(contentElement);
			accordionDiv.append(contentDiv);
			accordionDiv.style.flex = `0 1 ${Math.floor(
				100 / this.options.elementsPerRow
			)}%`;
			if (this.options.contentArray[i].order)
				accordionDiv.style.order = this.options.contentArray[i].order;
			document
				.querySelector(this.options.targetElement)
				.appendChild(accordionDiv);
			titleElement.addEventListener('click', () => {
				contentDiv.classList.toggle('hidden');
				titleDiv.querySelector('.accordion__arrow').classList.toggle('hidden');
			});
			titleDiv
				.querySelector('.accordion__arrow')
				.addEventListener('click', () => {
					contentDiv.classList.toggle('hidden');
					titleDiv
						.querySelector('.accordion__arrow')
						.classList.toggle('hidden');
				});
		}
	}
}
